gnupg: Python Package Documentation — gnupg unknown documentation

gnupg: Python Module Documentation
next | modules | index

# gnupg: Python Package Documentation

A Python interface for handling interactions with GnuPG, including keyfile generation, keyring maintainance, import and export, encryption and decryption, sending to and recieving from keyservers, and signing and verification.

Contents:

- gnupg package
  - gnupg module
  - meta module
  - parsers module
  - util module
  - About this fork
  - Previous Authors’ Documentation

# Source, license, & bug reports

The source code which was used to generate this documentation is accessible by clicking the little source links next to the docs. Current source code can be found in this github repository. The master branch always reflects the latest release, all releases are tagged with signed, annotated git tags, and the develop branch represents the state of the next release.

This package is released under GPLv3 or greater.

If you find a bug, or would like to request a feature, please use our public bugtracker on github. Patches warmly welcome.

# Indices and tables

- Index
- Module Index
- Search Page